lswifi is written and maintained by Josh Schmelzle:

Wizards
-------

- Josh Schmelzle (@joshschmelzle)

Contributors
------------

If you contribute code to this project, add your name below.

- Name (@handle)

Credits
-------

Thanks to many other makers contributions to open source that have inspired ideas for this project. Python, nmap, horst, tcpdump, etc.

Special thanks to Helge Magnus Keck (@HelgeKeck). This project would not be where it is without him.
